@@ -21,9 +21,11 @@ class Command(object):
         pod_name = util.get_hostname()
         ns = util.get_my_ns()
         key = "statefulset.kubernetes.io/pod-name"
-        l2 = [[f"{URL}/app/{ns}/{x[0]}", x[0], x[1]] for x in l1 
+        l2 = [[f"{URL}/app/{ns}/{x[0]}", x[0], x[1], "mine"] for x in l1 
                 if key in x[2] and pod_name == x[2][key]]
-        table = AsciiTable([["URI", "prefix", "port"]] + l2)
+        l3 = [[f"{URL}/app/{ns}/{x[0]}", x[0], x[1], "others"] for x in l1 
+                if key in x[2] and pod_name != x[2][key]]
+        table = AsciiTable([["URI", "prefix", "port", "owner"]] + l2 + l3)
         print(table.table)
 
     def create(self, relative_prefix, port):
